@@ -1,11 +1,8 @@
-use std::{
-    env,
-    time::Duration,
-    process::exit,
-};
+use std::{env, process::exit};
 use urlexpand;
 
-fn main() {
+#[tokio::main]
+async fn main() {
     let args: Vec<String> = env::args().collect();
     if args.len() == 1 {
         println!("pass a url to expand: (eg: ./unhorten https://bit.ly/3alqLKi)");
@@ -13,10 +10,11 @@ fn main() {
     }
     let url = args[1].to_owned();
 
-    println!("{}\nis_shortened? {}\nExpanded URL = {:?}",
+    println!(
+        "{}\nis_shortened? {}\nExpanded URL = {:?}",
         url,
         urlexpand::is_shortened(&url),
-        urlexpand::unshorten(&url, Some(Duration::from_secs(20)))
+        urlexpand::unshorten(&url, None).await.unwrap()
     );
     println!();
 }
