@@ -1,21 +1,25 @@
 /// List of domains for some known
 /// URL shortening services.
-pub(crate) static SERVICES: [&str; 73] = [
+pub(crate) static SERVICES: [&str; 86] = [
     "adf.ly",
     "adfoc.us",
     "amzn.to",
     "atominik.com",
+    "ay.gy",
     "b.link",
     "bit.ly",
     "bit.do",
     "bn.gy",
+    "branch.io",
     "buff.ly",
+    "ceesty.com",
     "chollo.to",
     "cli.re",
     "cli.fm",
     "cutt.ly",
     "cutt.us",
     "db.tt",
+    "f.ls",
     "fa.by",
     "fb.me",
     "flip.it",
@@ -24,6 +28,7 @@ pub(crate) static SERVICES: [&str; 73] = [
     "goo.gl",
     "gns.io",
     "hmm.rs",
+    "ht.ly",
     "hyperurl.co",
     "is.gd",
     "intamema.com",
@@ -33,10 +38,12 @@ pub(crate) static SERVICES: [&str; 73] = [
     "kutt.it",
     "ldn.im",
     "linklyhq.com",
+    "microify.com",
     "mzl.la",
     "nmc.sg",
     "nowlinks.net",
     "ow.ly",
+    "plu.sh",
     "q.gs",
     "qr.ae",
     "qr.net",
@@ -52,6 +59,8 @@ pub(crate) static SERVICES: [&str; 73] = [
     "shortcm.xyz",
     "shorturl.at",
     "smu.sg",
+    "smq.tc",
+    "snip.ly",
     "snipr.com",
     "snipurl.com",
     "snurl.com",
@@ -61,15 +70,19 @@ pub(crate) static SERVICES: [&str; 73] = [
     "t2m.io",
     "tiny.cc",
     "tiny.pl",
+    "tinyium.com",
     "tinyurl.com",
     "tiny.one",
     "tny.im",
     "tny.sh",
     "tr.im",
+    "trib.al",
     "u.to",
     "v.gd",
     "virg.in",
     "vzturl.com",
+    "waa.ai",
+    "washex.am",
     "x.co",
     "y2u.be",
     "yourwish.es",
